@@ -69,6 +69,7 @@ private Q_SLOTS:
     void testToolButtonStyleXmlGui();
     void testToolBarPosition();
     void testXmlGuiSwitching();
+    void testKAuthorizedDisableToggleAction();
 
 Q_SIGNALS:
     void signalAppearanceChanged();
@@ -111,6 +112,10 @@ void tst_KToolBar::initTestCase()
     testDataDir.removeRecursively();
     testDataDir.mkpath(QStringLiteral("."));
 
+    // setup action restriction so we can test whether this actually disables some functionality
+    KConfigGroup actionRestrictions(KSharedConfig::openConfig(), "KDE Action Restrictions");
+    actionRestrictions.writeEntry("action/options_show_toolbar", false);
+
     // copy a minimal icon theme to where KIconTheme will find it, in case oxygen-icons is not
     // installed
     copy_dir(QFINDTESTDATA("icons"), testDataDir);
@@ -290,7 +295,7 @@ void tst_KToolBar::testIconSizeXmlGui()
     KConfig config(QStringLiteral("tst_KToolBar"));
     KConfigGroup group(&config, "group");
     {
-        TestXmlGuiWindow kmw(m_xml);
+        TestXmlGuiWindow kmw(m_xml, "tst_ktoolbar.rc");
         kmw.createActions(QStringList() << QStringLiteral("go_up"));
         kmw.createGUI();
         KToolBar *mainToolBar = kmw.toolBarByName(QStringLiteral("mainToolBar"));
@@ -319,7 +324,7 @@ void tst_KToolBar::testIconSizeXmlGui()
         // was it the default size? (for the main toolbar, we only check that one)
         const bool usingDefaultSize = iconSize == KIconLoader::global()->currentSize(KIconLoader::MainToolbar);
         if (usingDefaultSize) {
-            QVERIFY(!group.groupList().contains("Toolbar mainToolBar"));
+            QVERIFY(!group.groupList().contains(QStringLiteral("Toolbar mainToolBar")));
             QVERIFY(!group.group("Toolbar mainToolBar").hasKey("IconSize"));
         } else {
             QVERIFY(group.group("Toolbar mainToolBar").hasKey("IconSize"));
@@ -467,7 +472,7 @@ void tst_KToolBar::testToolButtonStyleXmlGui()
     KConfig config(QStringLiteral("tst_KToolBar"));
     KConfigGroup group(&config, "group");
     {
-        TestXmlGuiWindow kmw(m_xml);
+        TestXmlGuiWindow kmw(m_xml, "tst_ktoolbar.rc");
         kmw.createActions(QStringList() << QStringLiteral("go_up"));
         kmw.createGUI();
         KToolBar *mainToolBar = kmw.toolBarByName(QStringLiteral("mainToolBar"));
@@ -523,7 +528,7 @@ void tst_KToolBar::deleteGlobalToolButtonStyleSetting()
 
 void tst_KToolBar::testToolBarPosition()
 {
-    TestXmlGuiWindow kmw(m_xml);
+    TestXmlGuiWindow kmw(m_xml, "tst_ktoolbar.rc");
     kmw.createActions(QStringList() << QStringLiteral("go_up"));
     kmw.createGUI();
     KToolBar *mainToolBar = kmw.toolBarByName(QStringLiteral("mainToolBar"));
@@ -541,7 +546,7 @@ void tst_KToolBar::testXmlGuiSwitching()
         "<MenuBar>\n"
         "</MenuBar>\n"
         "</gui>\n";
-    TestXmlGuiWindow kmw(windowXml);
+    TestXmlGuiWindow kmw(windowXml, "tst_ktoolbar.rc");
     kmw.createActions(QStringList() << QStringLiteral("go_up"));
     kmw.createGUI();
     TestGuiClient firstClient(m_xml);
@@ -610,7 +615,7 @@ void tst_KToolBar::testXmlGuiSwitching()
 
     // Recreate window and apply config; is hidden toolbar shown as expected?
     {
-        TestXmlGuiWindow kmw2(windowXml);
+        TestXmlGuiWindow kmw2(windowXml, "tst_ktoolbar.rc");
         kmw2.createActions(QStringList() << QStringLiteral("go_up"));
         kmw2.createGUI();
         TestGuiClient firstClient(m_xml);
@@ -643,6 +648,16 @@ void tst_KToolBar::testXmlGuiSwitching()
     }
 }
 
+void tst_KToolBar::testKAuthorizedDisableToggleAction()
+{
+    TestXmlGuiWindow kmw(m_xml, "tst_ktoolbar.rc");
+    kmw.createGUI();
+
+    foreach (KToolBar *toolbar, kmw.toolBars()) {
+        QVERIFY(!toolbar->toggleViewAction()->isEnabled());
+    }
+}
+
 bool tst_KToolBar::eventFilter(QObject *watched, QEvent *event)
 {
     Q_UNUSED(watched);
