@@ -24,6 +24,8 @@
     Boston, MA 02110-1301, USA.
 */
 
+#include "config-xmlgui.h"
+
 #include "kactioncollection.h"
 
 #include "kactioncategory.h"
@@ -33,7 +35,9 @@
 
 #include <kauthorized.h>
 #include <kconfiggroup.h>
-#include <kglobalaccel.h>
+#if HAVE_GLOBALACCEL
+# include <kglobalaccel.h>
+#endif
 #include <ksharedconfig.h>
 
 #include <QtXml/QDomDocument>
@@ -50,19 +54,24 @@ class KActionCollectionPrivate
 {
 public:
     KActionCollectionPrivate()
-        : m_parentGUIClient(0L),
+        : m_parentGUIClient(nullptr),
           configGroup(QStringLiteral("Shortcuts")),
           configIsGlobal(false),
           connectTriggered(false),
           connectHovered(false),
-          q(0)
+          q(nullptr)
 
     {
     }
 
     void setComponentForAction(QAction *action)
     {
-        if (!KGlobalAccel::self()->hasShortcut(action)) {
+#if HAVE_GLOBALACCEL
+        bool hasGlobalShortcut = KGlobalAccel::self()->hasShortcut(action);
+#else
+        bool hasGlobalShortcut = false;
+#endif
+        if (!hasGlobalShortcut) {
             action->setProperty("componentName", m_componentName);
             action->setProperty("componentDisplayName", m_componentDisplayName);
         }
@@ -78,7 +87,7 @@ public:
     QString m_componentName;
     QString m_componentDisplayName;
 
-    //! Remove a action from our internal bookkeeping. Returns NULL if the
+    //! Remove a action from our internal bookkeeping. Returns a nullptr if the
     //! action doesn't belong to us.
     QAction *unlistAction(QAction *);
 
@@ -111,7 +120,7 @@ KActionCollection::KActionCollection(QObject *parent, const QString &cName)
 }
 
 KActionCollection::KActionCollection(const KXMLGUIClient *parent)
-    : QObject(0)
+    : QObject(nullptr)
     , d(new KActionCollectionPrivate)
 {
     d->q = this;
@@ -137,7 +146,7 @@ void KActionCollection::clear()
 
 QAction *KActionCollection::action(const QString &name) const
 {
-    QAction *action = 0L;
+    QAction *action = nullptr;
 
     if (!name.isEmpty()) {
         action = d->actionByName.value(name);
@@ -171,7 +180,7 @@ void KActionCollection::setComponentName(const QString &cName)
         // As of now this only matters for global shortcuts. We could
         // thus relax the requirement and only refuse to change the component data
         // if we have actions with global shortcuts in this collection.
-        qWarning() << "this does not work on a KActionCollection containing actions!";
+        qCWarning(DEBUG_KXMLGUI) << "this does not work on a KActionCollection containing actions!";
     }
 
     if (!cName.isEmpty()) {
@@ -254,6 +263,7 @@ QAction *KActionCollection::addAction(const QString &name, QAction *action)
             // settings to disk. Both for local and global shortcuts.
             qCDebug(DEBUG_KXMLGUI) << "Registering action " << objectName << " under new name " << indexName;
             // If there is a global shortcuts it's a very bad idea.
+#if HAVE_GLOBALACCEL
             if (KGlobalAccel::self()->hasShortcut(action)) {
                 // In debug mode assert
                 Q_ASSERT(!KGlobalAccel::self()->hasShortcut(action));
@@ -261,6 +271,7 @@ QAction *KActionCollection::addAction(const QString &name, QAction *action)
                 qCritical() << "Changing action name from " << objectName << " to " << indexName << "\nignored because of active global shortcut.";
                 indexName = objectName;
             }
+#endif
         }
 
         // Set the new name
@@ -279,13 +290,13 @@ QAction *KActionCollection::addAction(const QString &name, QAction *action)
     Q_ASSERT(!action->objectName().isEmpty());
 
     // look if we already have THIS action under THIS name ;)
-    if (d->actionByName.value(indexName, 0) == action) {
+    if (d->actionByName.value(indexName, nullptr) == action) {
         // This is not a multi map!
         Q_ASSERT(d->actionByName.count(indexName) == 1);
         return action;
     }
 
-    if (!KAuthorized::authorizeKAction(indexName)) {
+    if (!KAuthorized::authorizeAction(indexName)) {
         // Disable this action
         action->setEnabled(false);
         action->setVisible(false);
@@ -345,7 +356,7 @@ void KActionCollection::removeAction(QAction *action)
 QAction *KActionCollection::takeAction(QAction *action)
 {
     if (!d->unlistAction(action)) {
-        return NULL;
+        return nullptr;
     }
 
     // Remove the action from all widgets
@@ -371,7 +382,7 @@ QAction *KActionCollection::addAction(KStandardAction::StandardAction actionType
     // pass 0 as parent, because if the parent is a KActionCollection KStandardAction::create automatically
     // adds the action to it under the default name. We would trigger the
     // warning about renaming the action then.
-    QAction *action = KStandardAction::create(actionType, receiver, member, 0);
+    QAction *action = KStandardAction::create(actionType, receiver, member, nullptr);
     // Give it a parent for gc.
     action->setParent(this);
     // Remove the name to get rid of the "rename action" warning above
@@ -445,6 +456,7 @@ void KActionCollection::setConfigGlobal(bool global)
 
 void KActionCollection::importGlobalShortcuts(KConfigGroup *config)
 {
+#if HAVE_GLOBALACCEL
     Q_ASSERT(config);
     if (!config || !config->exists()) {
         return;
@@ -469,6 +481,9 @@ void KActionCollection::importGlobalShortcuts(KConfigGroup *config)
             }
         }
     }
+#else
+    Q_UNUSED(config);
+#endif
 }
 
 void KActionCollection::readSettings(KConfigGroup *config)
@@ -505,6 +520,7 @@ void KActionCollection::readSettings(KConfigGroup *config)
 
 void KActionCollection::exportGlobalShortcuts(KConfigGroup *config, bool writeAll) const
 {
+#if HAVE_GLOBALACCEL
     Q_ASSERT(config);
     if (!config) {
         return;
@@ -555,6 +571,10 @@ void KActionCollection::exportGlobalShortcuts(KConfigGroup *config, bool writeAl
     }
 
     config->sync();
+#else
+    Q_UNUSED(config);
+    Q_UNUSED(writeAll);
+#endif
 }
 
 bool KActionCollectionPrivate::writeKXMLGUIConfigFile()
@@ -599,7 +619,9 @@ bool KActionCollectionPrivate::writeKXMLGUIConfigFile()
         bool bSameAsDefault = (action->shortcuts() == q->defaultShortcuts(action));
         qCDebug(DEBUG_KXMLGUI) << "name = " << actionName
                  << " shortcut = " << QKeySequence::listToString(action->shortcuts())
+#if HAVE_GLOBALACCEL
                  << " globalshortcut = " << QKeySequence::listToString(KGlobalAccel::self()->shortcut(action))
+#endif
                  << " def = " << QKeySequence::listToString(q->defaultShortcuts(action));
 
         // now see if this element already exists
@@ -629,7 +651,7 @@ void KActionCollection::writeSettings(KConfigGroup *config, bool writeAll, QActi
 {
     // If the caller didn't provide a config group we try to save the KXMLGUI
     // Configuration file. If that succeeds we are finished.
-    if (config == 0 && d->writeKXMLGUIConfigFile()) {
+    if (config == nullptr && d->writeKXMLGUIConfigFile()) {
         return;
     }
 
@@ -806,7 +828,7 @@ QAction *KActionCollectionPrivate::unlistAction(QAction *action)
 
     // Action not found.
     if (index == -1) {
-        return NULL;
+        return nullptr;
     }
 
     // An action collection can't have the same action twice.
