@@ -56,21 +56,21 @@ class KHelpMenuPrivate
 {
 public:
     KHelpMenuPrivate()
-        : mSwitchApplicationLanguage(0),
+        : mSwitchApplicationLanguage(nullptr),
           mActionsCreated(false),
-          mSwitchApplicationLanguageAction(0),
+          mSwitchApplicationLanguageAction(nullptr),
           mAboutData(KAboutData::applicationData())
     {
-        mMenu = 0;
-        mAboutApp = 0;
-        mAboutKDE = 0;
-        mBugReport = 0;
-        mDonateAction = 0;
-        mHandBookAction = 0;
-        mWhatsThisAction = 0;
-        mReportBugAction = 0;
-        mAboutAppAction = 0;
-        mAboutKDEAction = 0;
+        mMenu = nullptr;
+        mAboutApp = nullptr;
+        mAboutKDE = nullptr;
+        mBugReport = nullptr;
+        mDonateAction = nullptr;
+        mHandBookAction = nullptr;
+        mWhatsThisAction = nullptr;
+        mReportBugAction = nullptr;
+        mAboutAppAction = nullptr;
+        mAboutKDEAction = nullptr;
     }
     ~KHelpMenuPrivate()
     {
@@ -152,9 +152,7 @@ void KHelpMenuPrivate::createActions(KHelpMenu *q)
     }
 
     if (KAuthorized::authorizeAction(QStringLiteral("switch_application_language"))) {
-        if (KLocalizedString::availableApplicationTranslations().count() > 1) {
-            mSwitchApplicationLanguageAction = KStandardAction::create(KStandardAction::SwitchApplicationLanguage, q, SLOT(switchApplicationLanguage()), q);
-        }
+        mSwitchApplicationLanguageAction = KStandardAction::create(KStandardAction::SwitchApplicationLanguage, q, SLOT(switchApplicationLanguage()), q);
     }
 
     if (KAuthorized::authorizeAction(QStringLiteral("help_about_app"))) {
@@ -170,7 +168,7 @@ void KHelpMenuPrivate::createActions(KHelpMenu *q)
 QMenu *KHelpMenu::menu()
 {
     if (!d->mMenu) {
-        d->mMenu = new QMenu();
+        d->mMenu = new QMenu(d->mParent);
         connect(d->mMenu, SIGNAL(destroyed()), this, SLOT(menuDestroyed()));
 
         d->mMenu->setTitle(i18n("&Help"));
@@ -260,7 +258,7 @@ QAction *KHelpMenu::action(MenuId id) const
         break;
     }
 
-    return 0;
+    return nullptr;
 }
 
 void KHelpMenu::appHelpActivated()
@@ -363,25 +361,25 @@ void KHelpMenu::dialogFinished()
 void KHelpMenu::timerExpired()
 {
     if (d->mAboutKDE && !d->mAboutKDE->isVisible()) {
-        delete d->mAboutKDE; d->mAboutKDE = 0;
+        delete d->mAboutKDE; d->mAboutKDE = nullptr;
     }
 
     if (d->mBugReport && !d->mBugReport->isVisible()) {
-        delete d->mBugReport; d->mBugReport = 0;
+        delete d->mBugReport; d->mBugReport = nullptr;
     }
 
     if (d->mSwitchApplicationLanguage && !d->mSwitchApplicationLanguage->isVisible()) {
-        delete d->mSwitchApplicationLanguage; d->mSwitchApplicationLanguage = 0;
+        delete d->mSwitchApplicationLanguage; d->mSwitchApplicationLanguage = nullptr;
     }
 
     if (d->mAboutApp && !d->mAboutApp->isVisible()) {
-        delete d->mAboutApp; d->mAboutApp = 0;
+        delete d->mAboutApp; d->mAboutApp = nullptr;
     }
 }
 
 void KHelpMenu::menuDestroyed()
 {
-    d->mMenu = 0;
+    d->mMenu = nullptr;
 }
 
 void KHelpMenu::contextHelpActivated()
