@@ -40,7 +40,7 @@ class KActionCollection;
  * The widgets provides support for conflict handling. See
  * setCheckForConflictsAgainst() for more information.
  *
- * \image html kkeysequencewidget.png "KDE Key Sequence Widget"
+ * \image html kkeysequencewidget.png "KKeySequenceWidget"
  *
  * @author Mark Donohoe <donohoe@kde.org>
  * @internal
@@ -49,8 +49,6 @@ class KXMLGUI_EXPORT KKeySequenceWidget: public QWidget
 {
     Q_OBJECT
 
-    Q_FLAGS(ShortcutTypes)
-
     Q_PROPERTY(
         bool multiKeyShortcutsAllowed
         READ multiKeyShortcutsAllowed
@@ -79,7 +77,7 @@ public:
     /**
     * Constructor.
     */
-    explicit KKeySequenceWidget(QWidget *parent = 0);
+    explicit KKeySequenceWidget(QWidget *parent = nullptr);
 
     /**
     * Destructs the widget.
@@ -100,6 +98,7 @@ public:
         GlobalShortcuts = 0x04      //!< Check against global shortcuts. @see KGlobalAccel
     };
     Q_DECLARE_FLAGS(ShortcutTypes, ShortcutType)
+    Q_FLAG(ShortcutTypes)
 
     /**
      * Configure if the widget should check for conflicts with existing
@@ -122,7 +121,7 @@ public:
      * manually. It's your responsibility to save that change later when
      * you think it is appropriate.
      *
-     * 2. Call applyStealShortcut and KKeySequenceWidget will steal the
+     * 2. Call applyStealShortcut() and KKeySequenceWidget will steal the
      * shortcut. This will save the actionCollections the shortcut is part
      * of so make sure it doesn't inadvertly save some unwanted changes
      * too. Read its documentation for some limitation when handling
@@ -194,7 +193,7 @@ public:
     //@}
 
     /**
-     * Checks whether the key sequence @a seq is available to grab.
+     * Checks whether the key sequence @p seq is available to grab.
      *
      * The sequence is checked under the same rules as if it has been typed by
      * the user. This method is useful if you get key sequences from another
@@ -214,8 +213,8 @@ public:
      *
      * @see setCheckForConflictsAgainst()
      *
-     * If a KAction with a conflicting shortcut is found inside this list and
-     * its shortcut can be configured (KAction::isShortcutConfigurable()
+     * If a QAction with a conflicting shortcut is found inside this list and
+     * its shortcut can be configured (KActionCollection::isShortcutConfigurable()
      * returns true) the user will be prompted whether to steal the shortcut
      * from this action.
      *
