@@ -134,10 +134,10 @@ void KMWSessionManager::saveState(QSessionManager &sm)
     KConfigGui::setSessionConfig(sm.sessionId(), sm.sessionKey());
 
     KConfig *config = KConfigGui::sessionConfig();
-    if (KMainWindow::memberList().count()) {
+    if (!KMainWindow::memberList().isEmpty()) {
         // According to Jochen Wilhelmy <digisnap@cs.tu-berlin.de>, this
         // hook is useful for better document orientation
-        KMainWindow::memberList().first()->saveGlobalProperties(config);
+        KMainWindow::memberList().at(0)->saveGlobalProperties(config);
     }
 
     int n = 0;
@@ -216,14 +216,12 @@ KMainWindow::KMainWindow(KMainWindowPrivate &dd, QWidget *parent, Qt::WindowFlag
 void KMainWindowPrivate::init(KMainWindow *_q)
 {
     q = _q;
-#if QT_VERSION >= QT_VERSION_CHECK(5, 6, 0)
     QGuiApplication::setFallbackSessionManagementEnabled(false);
-#endif
-    q->setAnimated(q->style()->styleHint(QStyle::SH_Widget_Animate, 0, q));
+    q->setAnimated(q->style()->styleHint(QStyle::SH_Widget_Animate, nullptr, q));
 
     q->setAttribute(Qt::WA_DeleteOnClose);
 
-    helpMenu = 0;
+    helpMenu = nullptr;
 
     //actionCollection()->setWidget( this );
 #if 0
@@ -243,8 +241,8 @@ void KMainWindowPrivate::init(KMainWindow *_q)
     KAboutData aboutData(KAboutData::applicationData());
     if (aboutData.translators().isEmpty()) {
         aboutData.setTranslator(
-                i18ndc(Q_NULLPTR, "NAME OF TRANSLATORS", "Your names"),
-                i18ndc(Q_NULLPTR, "EMAIL OF TRANSLATORS", "Your emails"));
+                i18ndc(nullptr, "NAME OF TRANSLATORS", "Your names"),
+                i18ndc(nullptr, "EMAIL OF TRANSLATORS", "Your emails"));
 
         KAboutData::setApplicationData(aboutData);
     }
@@ -253,8 +251,8 @@ void KMainWindowPrivate::init(KMainWindow *_q)
     autoSaveSettings = false;
     autoSaveWindowSize = true; // for compatibility
     //d->kaccel = actionCollection()->kaccel();
-    settingsTimer = 0;
-    sizeTimer = 0;
+    settingsTimer = nullptr;
+    sizeTimer = nullptr;
 
     dockResizeListener = new DockResizeListener(_q);
     letDirtySettings = true;
@@ -411,7 +409,7 @@ QMenu *KMainWindow::helpMenu(const QString &aboutAppText, bool showWhatsThis)
         }
 
         if (!d->helpMenu) {
-            return 0;
+            return nullptr;
         }
     }
 
@@ -805,7 +803,7 @@ bool KMainWindow::event(QEvent *ev)
 {
     K_D(KMainWindow);
     switch (ev->type()) {
-#ifdef Q_OS_WIN
+#if defined(Q_OS_WIN) || defined(Q_OS_OSX)
     case QEvent::Move:
 #endif
     case QEvent::Resize:
@@ -882,7 +880,7 @@ void KMainWindowPrivate::_k_slotSettingsChanged(int category)
     // At this level (KMainWindow) the only thing we need to restore is the
     // animations setting (whether the user wants builtin animations or not).
 
-    q->setAnimated(q->style()->styleHint(QStyle::SH_Widget_Animate, 0, q));
+    q->setAnimated(q->style()->styleHint(QStyle::SH_Widget_Animate, nullptr, q));
 }
 
 void KMainWindowPrivate::_k_slotSaveAutoSaveSize()
