@@ -31,6 +31,9 @@
 #include <QSharedPointer>
 #include <QStandardPaths>
 #include <QDebug>
+#if QT_VERSION >= QT_VERSION_CHECK(5, 9, 0)
+#include <QtCore/private/qlocale_p.h>
+#endif
 
 #include "kswitchlanguagedialog_p.h"
 
@@ -61,7 +64,12 @@ static QByteArray getApplicationSpecificLanguage(const QByteArray &defaultCode =
     return settings->value(qAppName(), defaultCode).toByteArray();
 }
 
-static void setApplicationSpecificLanguage(const QByteArray &languageCode)
+namespace KDEPrivate
+{
+
+Q_COREAPP_STARTUP_FUNCTION(initializeLanguages)
+
+void setApplicationSpecificLanguage(const QByteArray &languageCode)
 {
     QSettingsPtr settings = localeOverridesSettings();
     settings->beginGroup(QStringLiteral("Language"));
@@ -73,7 +81,7 @@ static void setApplicationSpecificLanguage(const QByteArray &languageCode)
     }
 }
 
-static void initializeLanguages()
+void initializeLanguages()
 {
     const QByteArray languageCode = getApplicationSpecificLanguage();
 
@@ -84,14 +92,19 @@ static void initializeLanguages()
         } else {
             qputenv("LANGUAGE", languageCode + ":" + languages);
         }
+
+#if QT_VERSION >= QT_VERSION_CHECK(5, 9, 0)
+        // Ideally setting the LANGUAGE would change the default QLocale too
+        // but unfortunately this is too late since the QCoreApplication constructor
+        // already created a QLocale at this stage so we need to set the reset it
+        // by triggering the creation and destruction of a QSystemLocale
+        // this is highly dependant on Qt internals, so may break, but oh well
+        QSystemLocale *dummy = new QSystemLocale();
+        delete dummy;
+#endif
     }
 }
 
-Q_COREAPP_STARTUP_FUNCTION(initializeLanguages)
-
-namespace KDEPrivate
-{
-
 struct LanguageRowData {
     LanguageRowData()
     {
@@ -330,33 +343,24 @@ static bool stripCountryCode(QString *languageCode)
 
 void KSwitchLanguageDialogPrivate::fillApplicationLanguages(KLanguageButton *button)
 {
-    QLocale defaultLocale;
-    QLocale cLocale(QLocale::C);
-    QLocale::setDefault(cLocale);
+    const QLocale cLocale(QLocale::C);
     QSet<QString> insertedLanguges;
 
     const QList<QLocale> allLocales = QLocale::matchingLocales(QLocale::AnyLanguage, QLocale::AnyScript, QLocale::AnyCountry);
     foreach(const QLocale &l, allLocales) {
-        QString languageCode = l.name();
         if (l != cLocale) {
-            const QString nativeName = l.nativeLanguageName();
-            // For some languages the native name might be empty.
-            // In this case use the non native language name as fallback.
-            // See: QTBUG-51323
-            const QString languageName = nativeName.isEmpty() ? QLocale::languageToString(l.language()) : nativeName;
+            QString languageCode = l.name();
             if (!insertedLanguges.contains(languageCode) && KLocalizedString::isApplicationTranslatedInto(languageCode)) {
-                button->insertLanguage(languageCode, languageName);
+                button->insertLanguage(languageCode);
                 insertedLanguges << languageCode;
             } else if (stripCountryCode(&languageCode)) {
                 if (!insertedLanguges.contains(languageCode) && KLocalizedString::isApplicationTranslatedInto(languageCode)) {
-                    button->insertLanguage(languageCode, languageName);
+                    button->insertLanguage(languageCode);
                     insertedLanguges << languageCode;
                 }
             }
         }
     }
-
-    QLocale::setDefault(defaultLocale);
 }
 
 QStringList KSwitchLanguageDialogPrivate::applicationLanguageList()
