@@ -36,7 +36,7 @@ void ActionList::plug(QWidget *container, int index) const
     QAction *before = nullptr; // Insert after end of widget's current actions (default).
 
     if ((index < 0) || (index > container->actions().count())) {
-        qWarning() << "Index " << index << " is not within range (0 - " << container->actions().count();
+        qCWarning(DEBUG_KXMLGUI) << "Index " << index << " is not within range (0 - " << container->actions().count();
     } else if (index != container->actions().count()) {
         before = container->actions().at(index);    // Insert before indexed action.
     }
@@ -111,7 +111,7 @@ ContainerNode *ContainerNode::findContainer(const QString &_name, bool tag)
         }
     }
 
-    return 0;
+    return nullptr;
 }
 
 /*
@@ -460,7 +460,7 @@ int ContainerNode::calcMergingIndex(const QString &mergingName,
 void ContainerNode::dump(int offset)
 {
     QString indent; indent.fill(QLatin1Char(' '), offset);
-    qDebug() << qPrintable(indent) << name << tagName << groupName << mergingName << mergingIndices;
+    qCDebug(DEBUG_KXMLGUI) << qPrintable(indent) << name << tagName << groupName << mergingName << mergingIndices;
     Q_FOREACH (ContainerNode *child, children) {
         child->dump(offset + 2);
     }
@@ -494,7 +494,7 @@ int BuildHelper::calcMergingIndex(const QDomElement &element, MergingIndexList::
 }
 
 BuildHelper::BuildHelper(BuildState &state, ContainerNode *node)
-    : containerClient(0), ignoreDefaultMergingIndex(false), m_state(state),
+    : containerClient(nullptr), ignoreDefaultMergingIndex(false), m_state(state),
       parentNode(node)
 {
     // create a list of supported container and custom tags
@@ -776,7 +776,7 @@ void BuildHelper::processContainerElement(const QDomElement &e, const QString &t
                     bar->addXMLGUIClient(m_state.guiClient);
                 }
             } else {
-                qWarning() << "toolbar container is not a KToolBar";
+                qCWarning(DEBUG_KXMLGUI) << "toolbar container is not a KToolBar";
             }
         }
     }
@@ -824,8 +824,8 @@ void BuildState::reset()
     clientName.clear();
     actionListName.clear();
     actionList.clear();
-    guiClient = 0;
-    clientBuilder = 0;
+    guiClient = nullptr;
+    clientBuilder = nullptr;
 
     currentDefaultMergingIt = currentClientMergingIt = MergingIndexList::iterator();
 }
